﻿#pragma once

#include "Common\StepTimer.h"
#include "DeviceResources.h"
#include "Content\CircularTextRenderer.h"

// Renders Direct2D and 3D content on the screen.
namespace CircularText
{
	class CircularTextMain : public IDeviceNotify
	{
	public:
		CircularTextMain(const std::shared_ptr<DeviceResources>& deviceResources);
		~CircularTextMain();
		void CreateWindowSizeDependentResources();
		void StartTracking() {  }
		void TrackingUpdate(float positionX) { m_pointerLocationX = positionX; }
		void StopTracking() {  }
		bool IsTracking() { return false; }
		void StartRenderLoop();
		void StopRenderLoop();
		Concurrency::critical_section& GetCriticalSection() { return m_criticalSection; }

		// IDeviceNotify
		virtual void OnDeviceLost();
		virtual void OnDeviceRestored();

	private:
		void ProcessInput();
		void Update();
		bool Render();

		// Cached pointer to device resources.
		std::shared_ptr<DeviceResources> m_deviceResources;

		// Content renderer.
		std::unique_ptr<CircularTextRenderer> m_circularTextRenderer;

		Windows::Foundation::IAsyncAction^ m_renderLoopWorker;
		Concurrency::critical_section m_criticalSection;

		// Rendering loop timer.
		DX::StepTimer m_timer;

		// Track current input pointer position.
		float m_pointerLocationX;
	};
}