﻿#pragma once

#include <string>
#include "..\DeviceResources.h"
#include "..\Common\StepTimer.h"
#include "Polygon.h"

namespace CircularText
{
	class CircularTextRenderer
	{
	public:
		CircularTextRenderer(const std::shared_ptr<DeviceResources>& deviceResources);
		void CreateDeviceDependentResources();
		void ReleaseDeviceDependentResources();
        void CreateWindowSizeDependentResources();
		void Update(DX::StepTimer const& timer);
		void Render();

	private:
		// Cached pointer to device resources.
		std::shared_ptr<DeviceResources> m_deviceResources;

        // Geometry resources
        D2D1_RECT_F                                     m_geometryBounds;
        std::vector<Polygon>                            m_srcPolygons;
        std::vector<Polygon>                            m_dstPolygons;
        Microsoft::WRL::ComPtr<ID2D1PathGeometry>       m_pathGeometry;

		// Rendering resources
        Microsoft::WRL::ComPtr<ID2D1SolidColorBrush>    m_blackBrush;
        Microsoft::WRL::ComPtr<ID2D1SolidColorBrush>    m_blueBrush;
        Microsoft::WRL::ComPtr<ID2D1DrawingStateBlock>  m_stateBlock;
	};
}