﻿#pragma once

#include <string>
#include "..\DeviceResources.h"
#include "..\Common\StepTimer.h"
#include "Polygon.h"

namespace OccludedCircularText
{
	class OccludedCircularTextRenderer
	{
	public:
		OccludedCircularTextRenderer(const std::shared_ptr<DeviceResources>& deviceResources);
		void CreateDeviceDependentResources();
		void ReleaseDeviceDependentResources();
		void Update(DX::StepTimer const& timer);
		void Render();

        // Touch tracking methods
        void StartTracking();
        void TrackingUpdate(Windows::Foundation::Point ptDelta);
        void StopTracking();
        bool IsTracking() { return m_tracking; }

	private:
		// Cached pointer to device resources.
		std::shared_ptr<DeviceResources> m_deviceResources;

        // Geometry resources
        D2D1_RECT_F                                     m_geometryBounds;
        Microsoft::WRL::ComPtr<ID2D1PathGeometry>       m_srcPathGeometry;
        Microsoft::WRL::ComPtr<ID2D1PathGeometry>       m_frontPathGeometry;
        Microsoft::WRL::ComPtr<ID2D1PathGeometry>       m_backPathGeometry;

        HRESULT CreateGeometry(ID2D1Geometry * maskGeometry, 
                               D2D1_COMBINE_MODE combineMode, 
                               float rotationAngle, 
                               ID2D1PathGeometry ** pathGeometry);

        // Rendering resources
        float m_margin;
        Microsoft::WRL::ComPtr<ID2D1DrawingStateBlock>  m_stateBlock;
        Microsoft::WRL::ComPtr<ID2D1SolidColorBrush>    m_blackBrush;
        Microsoft::WRL::ComPtr<ID2D1SolidColorBrush>    m_blueBrush;
        Microsoft::WRL::ComPtr<ID2D1SolidColorBrush>    m_grayBrush;

		// Resources related to text rendering.
		std::wstring                                    m_text;
		Microsoft::WRL::ComPtr<IDWriteTextFormat>		m_textFormat;

        // Touch tracking variables
        bool m_tracking;
        float m_tiltAngle;
	};
}