﻿#pragma once

#include "Common\StepTimer.h"
#include "DeviceResources.h"
#include "Content\OccludedCircularTextRenderer.h"

// Renders Direct2D and 3D content on the screen.
namespace OccludedCircularText
{
	class OccludedCircularTextMain : public IDeviceNotify
	{
	public:
		OccludedCircularTextMain(const std::shared_ptr<DeviceResources>& deviceResources);
		~OccludedCircularTextMain();
		void CreateWindowSizeDependentResources();
        void StartTracking(Windows::Foundation::Point pt)
        {
            m_ptPrevious = pt;
            m_occludedCircularTextRenderer->StartTracking();
        }
        void TrackingUpdate(Windows::Foundation::Point pt)
        {
            m_ptDelta = Windows::Foundation::Point(pt.X - m_ptPrevious.X, pt.Y - m_ptPrevious.Y);
            m_ptPrevious = pt;
        }
        void StopTracking()
        {
            m_occludedCircularTextRenderer->StopTracking();
        }
        bool IsTracking()
        {
            return m_occludedCircularTextRenderer->IsTracking();
        }
        void StartRenderLoop();
		void StopRenderLoop();
		Concurrency::critical_section& GetCriticalSection() { return m_criticalSection; }

		// IDeviceNotify
		virtual void OnDeviceLost();
		virtual void OnDeviceRestored();

	private:
		void ProcessInput();
		void Update();
		bool Render();

		// Cached pointer to device resources.
		std::shared_ptr<DeviceResources> m_deviceResources;

		// TODO: Replace with your own content renderers.
        std::unique_ptr<OccludedCircularTextRenderer> m_occludedCircularTextRenderer;

		Windows::Foundation::IAsyncAction^ m_renderLoopWorker;
		Concurrency::critical_section m_criticalSection;

		// Rendering loop timer.
		DX::StepTimer m_timer;

        // Track current input pointer position.
        Windows::Foundation::Point m_ptDelta;
        Windows::Foundation::Point m_ptPrevious;
    };
}