﻿#pragma once

#include <string>
#include "..\DeviceResources.h"
#include "..\Common\StepTimer.h"
#include "Polygon.h"

namespace SpinningCircularText
{
	class SpinningCircularTextRenderer
	{
	public:
		SpinningCircularTextRenderer(const std::shared_ptr<DeviceResources>& deviceResources);
		void CreateDeviceDependentResources();
		void ReleaseDeviceDependentResources();
		void Update(DX::StepTimer const& timer);
		void Render();

        // Touch tracking methods
        void StartTracking();
        void TrackingUpdate(Windows::Foundation::Point ptDelta);
        void StopTracking();
        bool IsTracking() { return m_tracking; }

	private:
		// Cached pointer to device resources.
		std::shared_ptr<DeviceResources> m_deviceResources;

        // Geometry resources
        D2D1_RECT_F                                     m_geometryBounds;
        std::vector<Polygon>                            m_srcPolygons;
        std::vector<Polygon>                            m_dstPolygons;
        Microsoft::WRL::ComPtr<ID2D1PathGeometry>       m_pathGeometry;

        // Rendering resources
        Microsoft::WRL::ComPtr<ID2D1SolidColorBrush>    m_blackBrush;
        Microsoft::WRL::ComPtr<ID2D1SolidColorBrush>    m_blueBrush;
        Microsoft::WRL::ComPtr<ID2D1DrawingStateBlock>  m_stateBlock;

		// Resources related to text rendering.
		std::wstring                                    m_text;
		Microsoft::WRL::ComPtr<IDWriteTextFormat>		m_textFormat;

        // Touch tracking variables
        bool m_tracking;
        float m_tiltAngle;
	};
}