﻿#pragma once

#include "Common\StepTimer.h"
#include "DeviceResources.h"
#include "Content\SpinningCircularTextRenderer.h"

// Renders Direct2D and 3D content on the screen.
namespace SpinningCircularText
{
	class SpinningCircularTextMain : public IDeviceNotify
	{
	public:
		SpinningCircularTextMain(const std::shared_ptr<DeviceResources>& deviceResources);
		~SpinningCircularTextMain();
		void CreateWindowSizeDependentResources();
		void StartTracking(Windows::Foundation::Point pt) 
        { 
            m_ptPrevious = pt;
            m_spinningCircularTextRenderer->StartTracking(); 
        }
		void TrackingUpdate(Windows::Foundation::Point pt) 
        { 
            m_ptDelta = Windows::Foundation::Point(pt.X - m_ptPrevious.X, pt.Y - m_ptPrevious.Y);
            m_ptPrevious = pt;
        }
		void StopTracking() 
        { 
            m_spinningCircularTextRenderer->StopTracking(); 
        }
		bool IsTracking() 
        { 
            return m_spinningCircularTextRenderer->IsTracking(); 
        }
		void StartRenderLoop();
		void StopRenderLoop();
		Concurrency::critical_section& GetCriticalSection() { return m_criticalSection; }

		// IDeviceNotify
		virtual void OnDeviceLost();
		virtual void OnDeviceRestored();

	private:
		void ProcessInput();
		void Update();
		bool Render();

		// Cached pointer to device resources.
		std::shared_ptr<DeviceResources> m_deviceResources;

		// Content renderers.
		std::unique_ptr<SpinningCircularTextRenderer> m_spinningCircularTextRenderer;

		Windows::Foundation::IAsyncAction^ m_renderLoopWorker;
		Concurrency::critical_section m_criticalSection;

		// Rendering loop timer.
		DX::StepTimer m_timer;

		// Track current input pointer position.
        Windows::Foundation::Point m_ptDelta;
        Windows::Foundation::Point m_ptPrevious;
	};
}